==> flow-0.50.0.tar.gz: flow-0.50.0/tests/declaration_files_incremental_haste/test.sh <==
#!/bin/sh
FLOW=$1

OVERLAPPING_FILES="
  A.js
  ExplicitProvidesModuleSameName.js
  ImplicitProvidesModule.js
  external/_d3/min.js
  node_modules/qux/corge/lib/index.js
  node_modules/qux/docblock.js
"
DECL_FILES="$(echo "$OVERLAPPING_FILES" | sed -e "s/\.js/.js.flow/g") ExplicitProvidesModuleDifferentNameDefinitions.js.flow"
IMPL_FILES="$OVERLAPPING_FILES ExplicitProvidesModuleDifferentName.js md5.js ws/index.js ws/test/client.js"

ignore_files() {
  for file in $1; do
    mv "$file" "$file.ignored" 2>&1
  done
}

use_files() {
  for file in $1; do
    mv "$file.ignored" "$file" 2>&1
  done
}

printf "======Start off with the .js files but without the .flow file======\n"
"$FLOW" status .
use_files "$DECL_FILES"
"$FLOW" force-recheck $DECL_FILES
"$FLOW" status .
ignore_files "$DECL_FILES"
"$FLOW" force-recheck $DECL_FILES
"$FLOW" status .

printf "\n\n======Start off with the .js files and the .flow file======\n"
"$FLOW" stop .
use_files "$DECL_FILES"
"$FLOW" start . --all --wait

"$FLOW" status .
ignore_files "$DECL_FILES"
"$FLOW" force-recheck $DECL_FILES
"$FLOW" status .
use_files "$DECL_FILES"
"$FLOW" force-recheck $DECL_FILES
"$FLOW" status .

printf "\n\n======Start off without the .js files and with the .flow file======\n"
"$FLOW" stop .
ignore_files "$IMPL_FILES"
"$FLOW" start . --all --wait

"$FLOW" status .
use_files "$IMPL_FILES"
"$FLOW" force-recheck $IMPL_FILES
"$FLOW" status .
ignore_files "$IMPL_FILES"
"$FLOW" force-recheck $IMPL_FILES
"$FLOW" status .

# reset
use_files "$IMPL_FILES"
ignore_files "$DECL_FILES"

==> flow-0.52.0.tar.gz: flow-0.52.0/tests/declaration_files_incremental_haste/test.sh <==
#!/bin/bash
. ../assert.sh
FLOW=$1

OVERLAPPING_FILES="
  A.js
  ExplicitProvidesModuleSameName.js
  ImplicitProvidesModule.js
  external/_d3/min.js
  node_modules/qux/corge/lib/index.js
  node_modules/qux/docblock.js
"
DECL_FILES="$(echo "$OVERLAPPING_FILES" | sed -e "s/\.js/.js.flow/g") ExplicitProvidesModuleDifferentNameDefinitions.js.flow"
IMPL_FILES="$OVERLAPPING_FILES ExplicitProvidesModuleDifferentName.js md5.js ws/index.js ws/test/client.js"

ignore_files() {
  for file in $1; do
    mv "$file" "$file.ignored" 2>&1
  done
}

use_files() {
  for file in $1; do
    mv "$file.ignored" "$file" 2>&1
  done
}

printf "======Start off with the .js files but without the .flow file======\n"
assert_errors "$FLOW" status .
use_files "$DECL_FILES"
assert_ok "$FLOW" force-recheck $DECL_FILES
assert_errors "$FLOW" status .
ignore_files "$DECL_FILES"
assert_ok "$FLOW" force-recheck $DECL_FILES
assert_errors "$FLOW" status .

printf "\n\n======Start off with the .js files and the .flow file======\n"
assert_ok "$FLOW" stop .
use_files "$DECL_FILES"
assert_ok "$FLOW" start . --all --wait

assert_errors "$FLOW" status .
ignore_files "$DECL_FILES"
assert_ok "$FLOW" force-recheck $DECL_FILES
assert_errors "$FLOW" status .
use_files "$DECL_FILES"
assert_ok "$FLOW" force-recheck $DECL_FILES
assert_errors "$FLOW" status .

printf "\n\n======Start off without the .js files and with the .flow file======\n"
assert_ok "$FLOW" stop .
ignore_files "$IMPL_FILES"
assert_ok "$FLOW" start . --all --wait

assert_errors "$FLOW" status .
use_files "$IMPL_FILES"
assert_ok "$FLOW" force-recheck $IMPL_FILES
assert_errors "$FLOW" status .
ignore_files "$IMPL_FILES"
assert_ok "$FLOW" force-recheck $IMPL_FILES
assert_errors "$FLOW" status .

# reset
use_files "$IMPL_FILES"
ignore_files "$DECL_FILES"
